@@ -13,18 +13,21 @@ def register():
         Employee,
         UserEmployee,
         User,
-        Property,
         Sequence,
         SequenceStrict,
         Date,
         CompanyConfigStart,
         Cron,
         CronCompany,
-        PartyConfiguration,
+        Configuration,
+        PartyConfigurationLang,
+        Party,
+        PartyLang,
         Rule,
         module='company', type_='model')
     Pool.register(
         CompanyConfig,
+        PartyReplace,
         module='company', type_='wizard')
     Pool.register(
         LetterReport,
