@@ -53,7 +53,7 @@ class Company(ModelSQL, ModelView):
 
     @classmethod
     def search_rec_name(cls, name, clause):
-        return [('party',) + tuple(clause[1:])]
+        return [('party.rec_name',) + tuple(clause[1:])]
 
     @classmethod
     def write(cls, companies, values, *args):
@@ -95,7 +95,8 @@ class Employee(ModelSQL, ModelView):
 
     @classmethod
     def search_rec_name(cls, name, clause):
-        return [('party',) + tuple(clause[1:])]
+        return [('party.rec_name',) + tuple(clause[1:])]
+
 
 class UserEmployee(ModelSQL):
     'User - Employee'
@@ -266,7 +267,8 @@ class User:
                             ])
                     company_id = Transaction().context['company']
                     if ((company_id and company_id in map(int, companies))
-                            or not company_id):
+                            or not company_id
+                            or Transaction().user == 0):
                         values['company'] = company_id
                 if ('employee' in fields_names
                         and 'employee' in Transaction().context):
@@ -275,7 +277,9 @@ class User:
                         employees = cls.read([user_id],
                             ['employees'])[0]['employees']
                     employee_id = Transaction().context['employee']
-                    if employee_id and employee_id in employees:
+                    if ((employee_id and employee_id in employees)
+                            or not employee_id
+                            or Transaction().user == 0):
                         values['employee'] = employee_id
         return result
 
